@@ -1,5 +1,4 @@
 require 'ai.core.core'
-local fmt = require "format"
 
 -- Settings
 mem.armour_run    = 40
@@ -38,6 +37,7 @@ function create ()
 
    mem.formation = merc_formations[ rnd.rnd(1,#merc_formations) ]
    mem.whiteknight = rnd.rnd() > 0.5 -- Not always white knight
+   mem.atk_skill = 0.5 + 0.5*rnd.sigma()
 
    -- Finish up creation
    create_post()
@@ -66,13 +66,12 @@ function hail ()
 
    -- Refuel
    mem.refuel = mem.refuel_base
-   mem.refuel_msg = fmt.f(_([["I'll supply your ship with fuel for {credits}."]]),
-         {credits=fmt.credits(mem.refuel)})
+   mem.refuel_msg = _([["I'll supply your ship with fuel for {credits}."]])
 
    -- Set up bribes
    mem.bribe = mem.bribe_base
    if mem.allowbribe or (mem.natural and mem.bribe_rng > 0.7) then
-      mem.bribe_prompt = fmt.f(_([["Your life is worth {credits} to me."]]), {credits=fmt.credits(mem.bribe)} )
+      mem.bribe_prompt = _([["Your life is worth {credits} to me."]])
       mem.bribe_paid = _([["Beat it."]])
    else
       mem.bribe_no = bribe_no_list[ rnd.rnd(1,#bribe_no_list) ]
@@ -80,7 +79,7 @@ function hail ()
 end
 
 -- taunts
-function taunt ( target, offense )
+function taunt( _target, offense )
    -- Only 20% of actually taunting.
    if rnd.rnd() > 0.2 then
       return
@@ -94,5 +93,5 @@ function taunt ( target, offense )
       taunts = taunt_list_defensive
    end
 
-   ai.pilot():comm(target, taunts[ rnd.rnd(1,#taunts) ])
+   return taunts[ rnd.rnd(1,#taunts) ]
 end
