@@ -29,7 +29,7 @@ local function update_wset()
       if k > max_slots then
          break
       end
-      weap_icons[k] = outfit.get( v.name ):icon()
+      weap_icons[k] = v.outfit:icon()
    end
 
    aset = pp:actives()
@@ -39,8 +39,8 @@ local function update_wset()
       if k > max_slots then
          break
       end
-      active_icons[k] = outfit.get( v.name ):icon()
-    end
+      active_icons[k] = v.outfit:icon()
+   end
 end
 
 
@@ -51,7 +51,7 @@ function create()
    --Get sizes
    screen_w, screen_h = gfx.dim()
    deffont_h = gfx.fontSize()
-   gui.viewport( 0, 0, screen_w, screen_h )
+   --gui.viewport( 0, 0, screen_w, screen_h )
 
    -- Bar structures
    bars.armour = {}
@@ -64,7 +64,7 @@ function create()
    bars.speed2 = {}
    bars.stress = {}
 
-   --Colors
+   --Colours
    col_txt_std = colour.new( 192/255, 198/255, 217/255 )
    col_txt_wrn = colour.new( 127/255,  31/255,  31/255 )
    col_txt_enm = colour.new( 222/255,  28/255,  28/255 )
@@ -83,31 +83,37 @@ function create()
 
    --Load Images
    local base = "gfx/gui/slimv2/"
-   player_pane = tex.open( base .. "main.png" )
-   bar_sheen = tex.open( base .. "sheen.png" )
-   bar_bg = tex.open( base .. "bar_bg.png" )
-   bars.armour.icon = tex.open( base .. "armour.png" )
-   bars.energy.icon = tex.open( base .. "energy.png" )
-   bars.fuel.icon = tex.open( base .. "fuel.png" )
-   bars.heat.icon = tex.open( base .. "heat.png" )
-   bars.shield.icon = tex.open( base .. "shield.png" )
-   bars.speed.icon = tex.open( base .. "speed.png" )
-   slotA = tex.open( base .. "slot1-3.png" )
-   slotAend = tex.open( base .. "slot1-3end.png" )
-   slotB = tex.open( base .. "slot4.png" )
-   slotBend = tex.open( base .. "slot4end.png" )
-   slotC = tex.open( base .. "slot.png" )
-   slotCend = tex.open( base .. "slotend.png" )
-   slotAe = tex.open( base .. "slot1e.png" )
-   slotBe = tex.open( base .. "slot2-3e.png" )
-   slotCe = tex.open( base .. "slot4e.png" )
-   cooldown = tex.open( base .. "cooldown.png", 6, 6 )
-   lockonA = tex.open( base .. "padlockA.png" )
-   lockonB = tex.open( base .. "padlockB.png" )
-   active =  tex.open( base .. "active.png" )
+   local function tex_open( name, sx, sy, basepath )
+      basepath = basepath or base
+      local t = tex.open( basepath .. name, sx, sy )
+      t:setWrap( "clamp" )
+      return t
+   end
+   player_pane = tex_open( "main" )
+   bar_sheen = tex_open( "sheen" )
+   bar_bg = tex_open( "bar_bg" )
+   bars.armour.icon = tex_open( "armour" )
+   bars.energy.icon = tex_open( "energy" )
+   bars.fuel.icon = tex_open( "fuel" )
+   bars.heat.icon = tex_open( "heat" )
+   bars.shield.icon = tex_open( "shield" )
+   bars.speed.icon = tex_open( "speed" )
+   slotA = tex_open( "slot1-3" )
+   slotAend = tex_open( "slot1-3end" )
+   slotB = tex_open( "slot4" )
+   slotBend = tex_open( "slot4end" )
+   slotC = tex_open( "slot" )
+   slotCend = tex_open( "slotend" )
+   slotAe = tex_open( "slot1e" )
+   slotBe = tex_open( "slot2-3e" )
+   slotCe = tex_open( "slot4e" )
+   cooldown = tex_open( "cooldown", 6, 6 )
+   lockonA = tex_open( "padlockA" )
+   lockonB = tex_open( "padlockB" )
+   active =  tex_open( "active" )
 
-   gui.targetPlanetGFX( tex.open( base .. "radar_planet.png", 2, 2 ) )
-   gui.targetPilotGFX(  tex.open( base .. "radar_ship.png", 2, 2 ) )
+   gui.targetSpobGFX( tex_open( "radar_planet", 2, 2 ) )
+   gui.targetPilotGFX(  tex_open( "radar_ship", 2, 2 ) )
 
    --Get positions
    --Radar
@@ -174,10 +180,10 @@ function create()
    bars.speed.y = bars.shield.y
 
    -- Cooldown pane.
-   cooldown_sheen = tex.open( "gfx/gui/slim/cooldown-sheen.png" )
-   cooldown_bg = tex.open( "gfx/gui/slim/cooldown-bg.png" )
-   cooldown_frame = tex.open( "gfx/gui/slim/cooldown-frame.png" )
-   cooldown_panel = tex.open( "gfx/gui/slim/cooldown-panel.png" )
+   cooldown_sheen = tex_open( "gfx/gui/slim/cooldown-sheen", nil, nil, "" )
+   cooldown_bg = tex_open( "gfx/gui/slim/cooldown-bg", nil, nil, "" )
+   cooldown_frame = tex_open( "gfx/gui/slim/cooldown-frame", nil, nil, "" )
+   cooldown_panel = tex_open( "gfx/gui/slim/cooldown-panel", nil, nil, "" )
    cooldown_frame_w, cooldown_frame_h = cooldown_frame:dim()
    cooldown_frame_x = (screen_w - cooldown_frame_w)/2.
    cooldown_frame_y = (screen_h - cooldown_frame_h)/2.
@@ -348,7 +354,7 @@ function render( dt, dt_mod )
    local armour, shield, stress = pp:health()
    local energy = pp:energy()
    local speed = pp:vel():dist()
-   local heat = pp:temp()
+   local heat = 0
    local fuel = player.fuel()
    local fuel_max = stats.fuel_max
    local jumps = player.jumps()
@@ -373,9 +379,11 @@ function render( dt, dt_mod )
 
          gfx.renderTexRaw( weap_icons[i], slot_x + slot_img_offs_x, slot_img_offs_y, slot_img_w, slot_img_w, 1, 1, 0, 0, 1, 1 ) --Image
 
-         if wset[i].temp > 0 then
-            gfx.renderRect( slot_x + slot_img_offs_x, slot_img_offs_y, slot_img_w, slot_img_w * wset[i].temp/2, col_slot_heat ) --Heat
+         --[[
+         if wset[i].heat > 0 then
+            gfx.renderRect( slot_x + slot_img_offs_x, slot_img_offs_y, slot_img_w, slot_img_w * wset[i].heat/2, col_slot_heat ) --Heat
          end
+         --]]
 
          --Cooldown
          local coolinglevel = wset[i].cooldown
@@ -445,9 +453,9 @@ function render( dt, dt_mod )
          gfx.renderRect( slot_x, 0, slot_w, slot_h, col_slot_bg ) --Background
 
          -- Draw a heat background for certain outfits. TODO: detect if the outfit is heat based somehow!
-         if aset[i].type == "Afterburner" then
-            gfx.renderRect( slot_x + slot_img_offs_x, slot_img_offs_y, slot_img_w, slot_img_w * aset[i].temp, col_slot_heat ) -- Background (heat)
-         end
+         --if aset[i].type == "Afterburner" then
+         --  gfx.renderRect( slot_x + slot_img_offs_x, slot_img_offs_y, slot_img_w, slot_img_w * aset[i].heat, col_slot_heat ) -- Background (heat)
+         --end
 
          gfx.renderTexRaw( active_icons[i], slot_x + slot_img_offs_x, slot_img_offs_y, slot_img_w, slot_img_w, 1, 1, 0, 0, 1, 1 ) --Image
 
@@ -532,7 +540,7 @@ function render( dt, dt_mod )
 
    --Heat
    txt = round(heat) .. "K"
-   heat = math.max( math.min( (heat - 250)/1.75, 100 ), 0 )
+   heat = 0
    col = col_txt_std
    if heat >= 80. then
       col = col_txt_wrn
@@ -573,5 +581,8 @@ function render( dt, dt_mod )
    gfx.print( true, time.str( time.get(), 2 ), time_x, time_y, col_txt_std, time_w, true )
 end
 
-function end_cooldown ()
+function cooldown_end ()
+end
+
+function update_effects ()
 end
