@@ -78,10 +78,10 @@ end
 function competitor1()
    if player.misnDone("Destroy the FLF base!") == true then
       tk.msg(_("I am here to win the championship"), _([["I am here to claim my place as this cycle's champion! I've prepared myself since the first day I piloted a ship. Trust me, I'm nearly invincible and my Vendetta is indestructible.
-    "Do you know who I am? I am the famous independent pilot who helped Dvaered High Command destroy the FLF base in the nebula! I managed to defeat lots of FLF fighters with my ship! I will tell you my adventures some other time, but for now, I need to concentrate."]]))
+   "Do you know who I am? I am the famous independent pilot who helped Dvaered High Command destroy the FLF base in the nebula! I managed to defeat lots of FLF fighters with my ship! I will tell you my adventures some other time, but for now, I need to concentrate."]]))
    else
       tk.msg(_("I am here to win the championship"), _([["Hello! I am here to claim my place as this cycle's champion! I've prepared myself since the first day I piloted a ship. Trust me, I'm nearly invincible and my Vendetta is indestructible.
-    "Did you know that the Vendetta is the best fighter in this part of the galaxy? It's the reason why every pilot who's won this championship had one."]]))
+   "Did you know that the Vendetta is the best fighter in this part of the galaxy? It's the reason why every pilot who's won this championship had one."]]))
    end
 end
 function competitor2()
@@ -102,7 +102,7 @@ function accept()
    mem.reward = 50e3
 
    if tk.yesno(_("Do you want to take part to a challenge?"), _([["Hello, I'm a member of the staff of the Dvaered dogfight challenge. Here are the rules: you need to take off with a fighter-class ship and to join your starting mark. After that, you will try to disable your opponent. Don't kill them; the security staff won't forgive that. It is forbidden to use missiles, so you won't be allowed to have those equipped while taking off. It's also forbidden to board the opponent's ship and to attack him before the signal is given. You are not allowed to land on any planet or jump away during the championship.
-    We are looking for pilots. Are you in?"]])) then
+   We are looking for pilots. Are you in?"]])) then
 
       misn.accept()
 
@@ -131,16 +131,16 @@ function beginbattle()
       mem.stage = 0
       --Give a name to the competitor
       local names = {
-	        _("The Nice Killer"),
-                _("Longship Victory"),
-                _("The Victim"),
-                _("Old Fellow"),
-                _("Angel of Grace"),
-                _("Easy Killer"),
-                _("The Unicorn"),
-                _("The White Knight"),
-                _("Spirit of St Jean"),
-                _("Nec Mergitur") }
+         _("The Nice Killer"),
+         _("Longship Victory"),
+         _("The Victim"),
+         _("Old Fellow"),
+         _("Angel of Grace"),
+         _("Easy Killer"),
+         _("The Unicorn"),
+         _("The White Knight"),
+         _("Spirit of St Jean"),
+         _("Nec Mergitur") }
       local reTry = true
 
       while reTry do  --Re-pick a name while it is in the usedNames list
@@ -199,13 +199,13 @@ function enter()
       if oppotype == ship.get("Hyena") or oppotype == ship.get("Shark") then
          opponent:outfitAdd("Tricon Zephyr Engine")
          opponent:outfitAdd("Milspec Orion 2301 Core System")
-         opponent:outfitAdd("S&K Ultralight Combat Plating")
+         opponent:outfitAdd("S&K Skirmish Plating")
       elseif oppotype == ship.get("Soromid Reaver") then
          bioship.simulate( opponent, bioship.maxstage( opponent ) )
       else
-         opponent:outfitAdd("Tricon Zephyr II Engine")
-         opponent:outfitAdd("Milspec Orion 3701 Core System")
-         opponent:outfitAdd("S&K Light Combat Plating")
+         opponent:outfitAdd("Tricon Zephyr Engine",2)
+         opponent:outfitAdd("Milspec Orion 2301 Core System",2)
+         opponent:outfitAdd("S&K Skirmish Plating",2)
       end
 
       -- Equipment
@@ -232,6 +232,7 @@ function enter()
 
       opponent:control()
       opponent:moveto(mispla:pos() + vec2.new( 1000,  1500))
+
       ai_setup.setup(opponent)
 
       --The TV and the security
@@ -333,11 +334,11 @@ function land()
       elseif mem.stage == 3 and spob.cur() == mispla then  --player will be paid
 
       if mem.level == 5 then  --you are the champion
-         tk.msg(_("You are the new champion"), fmt.f(_([[Congratulations! The staff pays you {credits}.]]), {credits=fmt.credits(mem.reward * 2^mem.level)}))
+         tk.msg(_("You are the new champion"), fmt.f(_([[Congratulations! The staff pays you {credits}.]]), {credits="#g"..fmt.credits(mem.reward * 2^mem.level).."#0"}))
       elseif mem.level == 4 then
-         tk.msg(_("You are the vice-champion"), fmt.f(_([[Congratulations! The staff pays you {credits}.]]), {credits=fmt.credits(mem.reward * 2^mem.level)}))
+         tk.msg(_("You are the vice-champion"), fmt.f(_([[Congratulations! The staff pays you {credits}.]]), {credits="#g"..fmt.credits(mem.reward * 2^mem.level).."#0"}))
       else
-         tk.msg(_("Thanks for playing"), fmt.f(_([[The staff pays you {credits}.]]), {credits=fmt.credits(mem.reward * 2^mem.level)}))
+         tk.msg(_("Thanks for playing"), fmt.f(_([[The staff pays you {credits}.]]), {credits="#g"..fmt.credits(mem.reward * 2^mem.level).."#0"}))
       end
 
       player.pay(mem.reward * 2^mem.level)
