@@ -13,8 +13,7 @@
 Mission Name: Deliver Cake
 Author: iwaschosen
 
-Plot: on Zhiru you meet the same girl who received the love letters,her name is Paddy. Asks if you'd be willing to run another delivery and work with Michal on food biz. she says the man is an entrepreneur, and is trying to build a Food business
- on {michalspob} where he will sell her baked goodies etc. asks if you can take recipes and plans to him on {michalspob}. Fills your cargo hold with cake which you don't like. You can sell cake or bring to Michal who will pay a lot of $ for the cake, player doesn’t know that he will get paid for cake he brings.
+Plot: on Zhiru you meet the same girl who received the love letters,her name is Paddy. Asks if you'd be willing to run another delivery and work with Michal on food biz. she says the man is an entrepreneur, and is trying to build a Food business on {michalspob} where he will sell her baked goodies etc. asks if you can take recipes and plans to him on {michalspob}. Fills your cargo hold with cake which you don't like. You can sell cake or bring to Michal who will pay a lot of $ for the cake, player doesn’t know that he will get paid for cake he brings.
 --]]
 local fmt = require "format"
 local neu = require "common.neutral"
@@ -31,11 +30,11 @@ mem.reward = 100e3
 local reward_per_tonne = 5e3
 
 local npc_name = _("Paddy")
-local npc_portrait = "neutral/unique/paddy.webp"
+local npc_portrait = "neutral/unique/paddy"
 local npc_image = portrait.getFullPath( npc_portrait )
 
 local npc2_name = _("Michal")
-local npc2_portrait = "neutral/unique/michal.webp"
+local npc2_portrait = "neutral/unique/michal"
 local npc2_image = portrait.getFullPath( npc2_portrait )
 
 function create () --No system shall be claimed by mission
