@@ -1,14 +1,15 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="Anxious Merchant">
- <priority>3</priority>
+ <unique/>
+ <priority>4</priority>
  <chance>5</chance>
  <location>Bar</location>
  <cond>
    local f = spob.cur():faction()
    if f then
       local ft = f:tags()
-      if ft.generic or ft.misn_cargo then
+      if ft.generic then
          return require("misn_test").reweight_active()
       end
    end
@@ -62,7 +63,9 @@ function create()
       mem.time_limit:add(time.new( 0, 0, math.floor((mem.num_jumps-1) / jumpsperstop) * stu_jumps ))
    end
 
-   mem.payment = 20 * (stu_distance + (stu_jumps / 10))
+   mem.payment = 14 * (stu_distance + (stu_jumps / 10))
+   -- Made unique so double payment
+   mem.payment = mem.payment*2
 
    -- Range of 5-10 tons for tier 0, 21-58 for tier 4.
    mem.cargo_size = rnd.rnd( 5 + 4 * tier, 10 + 12 * tier )
