@@ -152,13 +152,13 @@ function success ()
    mem.reward = mem.reward * alive_frac
 
    if alive_frac >= 1 then
-      vntk.msg( _("Success!"), fmt.f(_("You successfully escorted the trading convoy to the destination. There wasn't a single casualty, and you are rewarded the full amount of #g{credits}#0."), {credits=fmt.credits(mem.reward)}) )
+      vntk.msg( _("Success!"), fmt.f(_("You successfully escorted the trading convoy to the destination. There wasn't a single casualty, and you are rewarded the full amount of {credits}."), {credits="#g"..fmt.credits(mem.reward).."#0"}) )
       faction.get("Traders Society"):hit(rnd.rnd(2,3))
    elseif alive_frac >= 0.6 then
-      vntk.msg( _("Success with Casualties"), fmt.f(_("You've arrived with the trading convoy more or less intact. Your pay is docked slightly due to the loss of part of the convoy. You receive #g{credits}#0 of the original promised reward of {reward}."), {credits=fmt.credits(mem.reward), reward=fmt.credits(reward_orig)}) )
+      vntk.msg( _("Success with Casualties"), fmt.f(_("You've arrived with the trading convoy more or less intact. Your pay is docked slightly due to the loss of part of the convoy. You receive {credits} of the original promised reward of {reward}."), {credits="#g"..fmt.credits(mem.reward).."#0", reward=fmt.credits(reward_orig)}) )
       faction.get("Traders Society"):hit(1)
    else
-      vntk.msg( _("Success with Heavy Casualties"), fmt.f(_("You arrive with what's left of the convoy. It's not much, but it's better than nothing. You are paid a steeply discounted amount of #g{credits}#0 from the {reward} originally promised."), {credits=fmt.credits(mem.reward), reward=fmt.credits(reward_orig)}) )
+      vntk.msg( _("Success with Heavy Casualties"), fmt.f(_("You arrive with what's left of the convoy. It's not much, but it's better than nothing. You are paid a steeply discounted amount of {credits} from the {reward} originally promised."), {credits="#g"..fmt.credits(mem.reward).."#0", reward=fmt.credits(reward_orig)}) )
    end
    player.pay( mem.reward )
    pir.reputationNormalMission(rnd.rnd(2,3))
@@ -175,14 +175,16 @@ function trader_create( p )
 end
 
 local last_spammed = 0
-local unsafe = false
+--local unsafe = false
 -- Handle the convoy getting attacked.
 -- luacheck: globals trader_attacked
 function trader_attacked( p, attacker )
+   --[[
    unsafe = true
    p:control( false )
    p:setNoJump( true )
    p:setNoLand( true )
+   --]]
 
    -- Attackers have to be marked as hostile
    attacker:setHostile()
@@ -197,10 +199,12 @@ end
 
 function trader_safe()
    hook.timer( 3.0, "trader_safe" )
+   --[[
    if unsafe then
       unsafe = false
       escort.reset_ai()
    end
+   --]]
 end
 
 function spawn_ambush ()
