@@ -14,10 +14,10 @@ local _sfx
 local function _sfx_load ()
    audio = require 'love.audio'
    _sfx = {
-      bingo = audio.newSource( 'snd/sounds/jingles/success.ogg' ),
-      money = audio.newSource( 'snd/sounds/jingles/money.ogg' ),
-      victory = audio.newSource( 'snd/sounds/jingles/victory.ogg' ),
-      eerie = audio.newSource( 'snd/sounds/jingles/eerie.ogg' ),
+      bingo = audio.newSoundData( 'snd/sounds/jingles/success' ),
+      money = audio.newSoundData( 'snd/sounds/jingles/money' ),
+      victory = audio.newSoundData( 'snd/sounds/jingles/victory' ),
+      eerie = audio.newSoundData( 'snd/sounds/jingles/eerie' ),
    }
 end
 
@@ -27,8 +27,7 @@ end
 function lmisn.sfxVictory ()
    if not _sfx then _sfx_load() end
 
-   local sfx = _sfx.victory:clone()
-   luaspfx.sfx( false, nil, sfx )
+   luaspfx.sfx( false, nil, _sfx.victory )
 end
 
 --[[--
@@ -37,8 +36,7 @@ end
 function lmisn.sfxMoney ()
    if not _sfx then _sfx_load() end
 
-   local sfx = _sfx.money:clone()
-   luaspfx.sfx( false, nil, sfx )
+   luaspfx.sfx( false, nil, _sfx.money )
 end
 
 --[[--
@@ -47,8 +45,7 @@ end
 function lmisn.sfxBingo()
    if not _sfx then _sfx_load() end
 
-   local sfx = _sfx.bingo:clone()
-   luaspfx.sfx( false, nil, sfx )
+   luaspfx.sfx( false, nil, _sfx.bingo )
 end
 
 --[[--
@@ -57,8 +54,7 @@ end
 function lmisn.sfxEerie ()
    if not _sfx then _sfx_load() end
 
-   local sfx = _sfx.eerie:clone()
-   luaspfx.sfx( false, nil, sfx )
+   luaspfx.sfx( false, nil, _sfx.eerie )
 end
 
 --[[--
@@ -100,7 +96,7 @@ end
 --]]
 function lmisn.getNextSystem( nowsys, finalsys, hidden )
    if nowsys == finalsys or finalsys == nil then
-       return nowsys
+      return nowsys
    end
 
    local path = nowsys:jumpPath( finalsys, hidden )
@@ -194,14 +190,14 @@ end
    @usage
    local spobs = {}
    lmisn.getSysAtDistance( system.cur(), 1, 6,
-       function(s)
-           for i, v in ipairs(s:spobs()) do
-               if v:faction() == faction.get("Sirius") and v:class() == "M" then
-                   return true
-               end
-           end
-           return false
-       end )
+      function(s)
+         for i, v in ipairs(s:spobs()) do
+            if v:faction() == faction.get("Sirius") and v:class() == "M" then
+               return true
+            end
+         end
+         return false
+      end )
 
    if #spobs == 0 then misn.finish(false) end -- In case no suitable spobs are in range.
 
@@ -367,6 +363,27 @@ function lmisn.calculateDistance( origin_sys, origin_pos, dest_sys, dest_pos, pa
    return traveldist, jumps
 end
 
+--[[--
+Gets the closest jump to a position.
+
+   @tparam[opt=player.pos()] Vec2 pos Position to get closest jump to.
+   @tparam[opt=system.cur()] System sys System to get closest jump from location.
+--]]
+function lmisn.nearestJump( pos, sys )
+   pos = pos or player.pos()
+   sys = sys or system.cur()
+   local closest_j = nil
+   local closest = math.huge
+   for k,j in ipairs(sys:jumps(true)) do
+      local d = j:pos():dist2(pos)
+      if d < closest then
+         closest_j = j
+         closest = d
+      end
+   end
+   return closest_j
+end
+
 --[[--
    Wrapper for player.misnActive that works on a table of missions.
 
@@ -394,4 +411,31 @@ function lmisn.fail( reason )
    misn.finish(false)
 end
 
+local function check_player_tag( tag )
+   local pp = player.pilot()
+   if pp:ship():tags()[tag] then
+      return true
+   end
+   for k,o in ipairs(pp:outfitsList("all")) do
+      if o:tags()[tag] then
+         return true
+      end
+   end
+   return false
+end
+
+--[[--
+Returns whether or not the player is lucky.
+--]]
+function lmisn.is_lucky()
+   return check_player_tag( "lucky" )
+end
+
+--[[--
+Gets whether or not a ship is a luxury vessel.
+--]]
+function lmisn.is_luxury()
+   return check_player_tag( "luxury" )
+end
+
 return lmisn
