@@ -4,8 +4,9 @@
 local class = require 'class'
 local love = require 'love'
 local object = require 'love.object'
-local filesystem = require 'love.filesystem'
+--local filesystem = require 'love.filesystem'
 local love_math = require 'love.math'
+local fmt = require "format"
 
 local graphics = {
    _bgcol = naev.colour.new( 0, 0, 0, 1 ),
@@ -19,7 +20,7 @@ local graphics = {
 local function _mode(m)
    if     m=="fill" then return false
    elseif m=="line" then return true
-   else   error( string.format(_("Unknown fill mode '%s'"), m ) )
+   else   error( fmt.f("Unknown fill mode '{m}'", {m=m} ) )
    end
 end
 local function _H( x, y, r, sx, sy )
@@ -29,7 +30,7 @@ local function _H( x, y, r, sx, sy )
       -- Rendering to canvas
       local cw = graphics._canvas.t.w
       local ch = graphics._canvas.t.h
-      H = naev.transform.ortho( 0, cw, 0, ch, 1, -1 )
+      H = naev.transform.ortho( 0, cw, ch, 0, 1, -1 )
       local cs = 1/graphics._canvas.t.s
       H = H:scale( cs, cs )
    else
@@ -60,11 +61,14 @@ local function _gcol( c )
    return r, g, b, a
 end
 local function _scol( r, g, b, a )
-   if type(r)=="table" then
+   local t = type(r)
+   if t=="table" then
       a = r[4]
       b = r[3]
       g = r[2]
       r = r[1]
+   elseif t=='userdata' then
+      return r:clone()
    end
    return naev.colour.new( r, g, b, a or 1 )
 end
@@ -85,15 +89,16 @@ graphics.Image = class.inheritsFrom( graphics.Drawable )
 graphics.Image._type = "Image"
 function graphics.newImage( filename )
    local ttex
-   if type(filename)=='string' then
-      ttex = naev.tex.open( filesystem.newFile( filename ) )
-   elseif type(filename)=='table' and filename.type then
+   local ft = type(filename)
+   if ft=='string' then
+      ttex = naev.tex.open( filename )
+   elseif ft=='table' and filename.type then
       local ot = filename:type() -- codespell:ignore ot
       if ot=='ImageData' then -- codespell:ignore ot
-         ttex = naev.tex.open( filename.d, filename.w, filename.h )
+         ttex = naev.tex.new( filename.d, filename.w, filename.h )
       end
    -- Assume Naev texture
-   elseif type(filename)=='userdata' then
+   elseif ft=='userdata' then
       ttex = filename
    end
    if ttex ~= nil then
@@ -162,7 +167,7 @@ function graphics.Image:draw( ... )
    if canvas then
       s1 = canvas.w
       s2 = canvas.h
-      s3 = -1.0
+      s3 = 1.0
       s4 = love.h
    else
       s1 = love.w
@@ -217,8 +222,8 @@ end
 --]]
 function graphics.origin()
    local nw, nh = naev.gfx.dim()
-   local nx = -love.x
-   local ny = love.h+love.y-nh
+   local nx = love.x
+   local ny = love.y
    graphics._O = naev.transform.ortho( nx, nx+nw, ny+nh, ny, 1, -1 )
    graphics._T = { love_math.newTransform() }
 end
@@ -313,20 +318,25 @@ end
 function graphics.clear( ... )
    local arg = {...}
    local col
+   local t = type(arg[1])
    if #arg==0 then
       col = graphics._bgcol
-   elseif type(arg[1])=="number" then
+   elseif t=="number" then
       local r = arg[1]
       local g = arg[2]
       local b = arg[3]
       local a = arg[4] or 1
       col = _scol( r, g, b, a )
-   elseif type(arg[1])=="table" then
+   elseif t=="table" then
       local r = arg[1][1]
       local g = arg[1][2]
       local b = arg[1][3]
       local a = arg[1][4] or 1
       col = _scol( r, g, b, a )
+   elseif t=="userdata" then
+      col = arg[1]
+   else
+      error(fmt.f("unknown colour type '{t}'"), {t=t})
    end
    if graphics._canvas then
       graphics._canvas.canvas:clear( col )
@@ -388,13 +398,15 @@ function graphics.printf( text, ... )
    col = graphics._fgcol
 
    local H = _H( x, y+font.height, 0, 1, 1 )
-   local sx = graphics._T[1].T:get()[1][1] -- X scaling
+   --local sx = graphics._T[1].T:get()[1][1] -- X scaling
+   local sw, sh = graphics._T[1]:transformDim( 1, 0 )
+   local sx = math.sqrt( sw^2 + sh^2 )
    local wrapped = naev.gfx.printfWrap( font.font, text, limit/sx )
 
    local atype
    if align=="left" then
       atype = 1
-   elseif align=="center" then
+   elseif align=="center" or align=="centre" then -- codespell:ignore center
       atype = 2
    elseif align=="right" then
       atype = 3
@@ -424,10 +436,6 @@ function graphics.setScissor( x, y, width, height )
          y = y or 0
          width = width or love.w
          height = height or love.h
-
-         if graphics._canvas == nil then
-            y = love.h - y - height
-         end
          naev.gfx.setScissor( love.x+x, love.y+y, width, height )
       end
    else
@@ -540,7 +548,6 @@ function graphics.newShader( pixelcode, vertexcode )
    vertexcode = vertexcode or _vertexcode
 
    local prepend = [[
-#version 150
 #define _LOVE
 // Syntax sugar
 #define Image           sampler2D
@@ -553,12 +560,21 @@ function graphics.newShader( pixelcode, vertexcode )
 #define love_PixelCoord love_getPixelCoord()
 
 // Uniforms shared by pixel and vertex shaders
+#if GLSL_VERSION < 440
 uniform mat4 ViewSpaceFromLocal;
 uniform mat4 ClipSpaceFromView;
 uniform mat4 ClipSpaceFromLocal;
 uniform mat3 ViewNormalFromLocal;
 uniform vec4 love_ScreenSize;
-uniform vec4 ConstantColour = vec4(1.0);
+uniform vec4 ConstantColour;
+#else /* GLSL_VERSION < 440 */
+layout(location=0) uniform mat4 ViewSpaceFromLocal;
+layout(location=1) uniform mat4 ClipSpaceFromView;
+layout(location=2) uniform mat4 ClipSpaceFromLocal;
+layout(location=3) uniform mat3 ViewNormalFromLocal;
+layout(location=4) uniform vec4 love_ScreenSize;
+layout(location=5) uniform vec4 ConstantColour;
+#endif /* GLSL_VERSION < 440 */
 
 // Compatibility
 #define TransformMatrix             ViewSpaceFromLocal
@@ -570,42 +586,51 @@ uniform vec4 ConstantColour = vec4(1.0);
 #define PIXEL
 uniform sampler2D MainTex;
 
-in vec4 VaryingTexCoord;
-in vec4 VaryingColour;
-in vec2 VaryingPosition;
-out vec4 colour_out;
+#if GLSL_VERSION >= 440
+layout(location=0) in InterfBLock {
+#else /* GLSL_VERSION >= 440 */
+in InterfBLock {
+#endif /* GLSL_VERSION >= 440 */
+   vec4 VaryingTexCoord;
+   vec4 VaryingColour;
+   vec2 VaryingPosition;
+} IN;
+layout(location = 0) out vec4 colour_out;
 
 vec2 love_getPixelCoord() {
-   vec2 uv = love_ScreenSize.xy * (0.5*VaryingPosition+0.5);
-   uv.y = uv.y * love_ScreenSize.z + love_ScreenSize.w;
+   vec2 uv = love_ScreenSize.xy * (0.5*IN.VaryingPosition+0.5);
    return uv;
 }
 
 vec4 effect( vec4 vcolour, Image tex, vec2 texcoord, vec2 pixcoord );
 
 void main(void) {
-   love_PixelColour = effect( VaryingColour, MainTex, VaryingTexCoord.st, love_PixelCoord );
+   love_PixelColour = effect( IN.VaryingColour, MainTex, IN.VaryingTexCoord.st, love_PixelCoord );
 }
 ]]
    local vert = [[
 #define VERTEX
-in vec4 VertexPosition;
-in vec4 VertexTexCoord;
-in vec4 VertexColour;
+layout(location = 0) in vec4 VertexPosition;
+layout(location = 1) in vec4 VertexTexCoord;
 
-out vec4 VaryingTexCoord;
-out vec4 VaryingColour;
-out vec2 VaryingPosition;
+#if GLSL_VERSION >= 440
+layout(location=0) out InterfBLock {
+#else /* GLSL_VERSION >= 440 */
+out InterfBLock {
+#endif /* GLSL_VERSION >= 440 */
+   vec4 VaryingTexCoord;
+   vec4 VaryingColour;
+   vec2 VaryingPosition;
+} OUT;
 
 vec4 position( mat4 clipSpaceFromLocal, vec4 localPosition );
 
 void main(void) {
-    VaryingTexCoord  = VertexTexCoord;
-    VaryingTexCoord.y= 1.0 - VaryingTexCoord.y;
-    VaryingTexCoord  = ViewSpaceFromLocal * VaryingTexCoord;
-    VaryingColour     = ConstantColour;
-    love_Position    = position( ClipSpaceFromLocal, VertexPosition );
-    VaryingPosition  = love_Position.xy;
+   OUT.VaryingTexCoord = VertexTexCoord;
+   OUT.VaryingTexCoord = ViewSpaceFromLocal * VertexTexCoord;
+   OUT.VaryingColour   = ConstantColour;
+   love_Position       = position( ClipSpaceFromLocal, VertexPosition );
+   OUT.VaryingPosition = love_Position.xy;
 }
 ]]
    local s = graphics.Shader.new()
@@ -615,6 +640,7 @@ void main(void) {
          prepend..vert..vertexcode )
    -- Set some default uniform values for when post-process shaders are used
    s.shader:sendRaw( "love_ScreenSize", love.w, love.h, 1.0, 0.0 )
+   s.shader:sendRaw( "ConstantColour", 1, 1, 1, 1 )
    return s
 end
 function graphics.setShader( shader )
