@@ -34,18 +34,18 @@ local vn = {
       _buffer = "",
       _title = nil,
       _globalalpha = 1,
-      --_soundTalk = audio.newSource( "snd/sounds/ui/letter0.wav" ),
+      --_soundTalk = audio.newSource( "snd/sounds/ui/letter0" ),
       _pitchValues = {0.7, 0.8, 1.0, 1.2, 1.3},
       _buffer_y = 0,
    },
    transitions = transitions,
    _sfx = {
-      bingo = audio.newSource( 'snd/sounds/jingles/success.ogg' ),
-      eerie = audio.newSource( 'snd/sounds/jingles/eerie.ogg' ),
-      money = audio.newSource( 'snd/sounds/jingles/money.ogg' ),
-      victory = audio.newSource( 'snd/sounds/jingles/victory.ogg' ),
+      bingo = audio.newSoundData( 'snd/sounds/jingles/success' ),
+      eerie = audio.newSoundData( 'snd/sounds/jingles/eerie' ),
+      money = audio.newSoundData( 'snd/sounds/jingles/money' ),
+      victory = audio.newSoundData( 'snd/sounds/jingles/victory' ),
       ui = {
-         option = audio.newSource( 'snd/sounds/ui/happy.wav' ),
+         option = audio.newSource( 'snd/sounds/ui/happy' ),
       },
    },
 }
@@ -681,10 +681,10 @@ function vn.StateCharacter.new( character, remove )
    return s
 end
 local function _getpos( pos )
-   pos = pos or "center"
+   pos = pos or "centre"
    if type(pos)=="number" then
       return pos
-   elseif pos == "center" then
+   elseif pos == "center" or pos == "centre" then -- codespell:ignore center
       return 0.5
    elseif pos == "left" then
       return 0.25
@@ -995,11 +995,13 @@ function vn.StateMenu.new( items, handler )
    s._items = nil
    s.handler = handler
    s._choose = vn.StateMenu._choose
+   s._visited = {}
    return s
 end
 function vn.StateMenu:_init()
    -- Check to see if function
    if type(self.items)=="function" then
+      self._visited = {} -- Always clear for functions
       self._items = self.items()
    else
       self._items = self.items
@@ -1075,7 +1077,11 @@ function vn.StateMenu:_draw()
       end
       vn.setColour( col )
       graphics.rectangle( "fill", gx+x, gy+y, w, h )
-      vn.setColour( {0.7, 0.7, 0.7} )
+      if self._visited[k] then
+         vn.setColour( {0.6, 0.6, 0.6} )
+      else
+         vn.setColour( {0.8, 0.8, 0.8} )
+      end
       graphics.printf( text, font, gx+x+tb, gy+y+tb, w-tb*2 )
    end
 end
@@ -1109,6 +1115,7 @@ function vn.StateMenu:_choose( n )
       what  = self._items[n][1],
       colour= vn._default._bufcol,
    }
+   self._visited[n] = true
    _finish( self )
 end
 --[[
@@ -1281,6 +1288,12 @@ Makes a character say something.
 --]]
 function vn.Character:say( what, noclear, nowait ) return vn.say( self.who, what, noclear, nowait ) end
 vn.Character_mt = { __index = vn.Character, __call = vn.Character.say }
+local SEARCHPATH = {
+   "",
+   "gfx/vn/characters/",
+}
+local SEARCHEXT = naev.supported_image_ext()
+table.insert( SEARCHEXT, 1, "" )
 --[[--
 Creates a new character without adding it to the VN.
 <em>Note</em> The character can be added with vn.newCharacter.
@@ -1301,16 +1314,15 @@ function vn.Character.new( who, params )
       if timg=='function' then
          img = pimage()
       elseif timg=='string' then
-         local searchpath = {
-            "",
-            "gfx/vn/characters/",
-         }
-         for k,s in ipairs(searchpath) do
-            local info = filesystem.getInfo( s..pimage )
-            if info ~= nil then
-               img = graphics.newImage( s..pimage )
-               if img ~= nil then
-                  break
+         for k,s in ipairs(SEARCHPATH) do
+            for i, ext in ipairs(SEARCHEXT) do
+               local name = s..pimage..ext
+               local info = filesystem.getInfo( name )
+               if info ~= nil then
+                  img = graphics.newImage( name )
+                  if img ~= nil then
+                     break
+                  end
                end
             end
          end
@@ -1323,6 +1335,9 @@ function vn.Character.new( who, params )
          end
       elseif pimage._type=="ImageData" then
          img = graphics.newImage( pimage )
+      -- vn code assumes lua graphics image, so rewrap if we think it's a rust-side texture
+      elseif type(pimage)=="userdata" then
+         img = graphics.newImage( pimage )
       else
          img = pimage
       end
@@ -1475,7 +1490,7 @@ Moves a character to another position.
 
    @see vn.animation
    @tparam Character c Character to move.
-   @tparam[opt="center"] string|number pos Position to move to. Can be either a [0,1] value, "center", "left", "right", "farleft", or "farright".
+   @tparam[opt="centre"] string|number pos Position to move to. Can be either a [0,1] value, "centre", "left", "right", "farleft", or "farright".
 --]]
 function vn.move( c, pos )
    local function runinit ()
@@ -1548,7 +1563,7 @@ Inserts a jump. This skips to a certain label.
 --]]
 function vn.jump( label )
    if vn._started then
-      vn._jump( label )
+      return vn._jump( label )
    end
    table.insert( vn._states, vn.StateJump.new( label ) )
 end
@@ -1564,7 +1579,6 @@ This gets automatically reset when the VN finishes.
    @tparam boolean dontstop Don't stop other music.
 --]]
 function vn.music( filename, params, dontstop )
-   vn._checkstarted()
    local m = {}
    if filename == nil then
       vn.func( function ()
@@ -1574,7 +1588,7 @@ function vn.music( filename, params, dontstop )
    else
       vn.func( function ()
          if not dontstop then
-            music.stop(true)
+            music.pause(true)
             lmusic.stop()
          end
          vn._handle_music = true
@@ -1648,9 +1662,7 @@ function vn.done( ... )
       vn._update = nil
       if vn._handle_music then
          lmusic.stop()
-         if not music.isPlaying() then
-            music.play()
-         end
+         music.play()
       end
    end )
    vn.transition( ... )
@@ -1713,7 +1725,10 @@ Runs a specified function and continues execution.
    @tparam func func Function to run.
 --]]
 function vn.func( func )
-   vn._checkstarted()
+   if vn._started then
+      func()
+      return
+   end
    local s = vn.State.new()
    s._init = function (self)
       func()
@@ -1736,9 +1751,7 @@ function vn.sfx( sfx, params )
    end
    local s = vn.State.new()
    s._init = function (state)
-      local _sfx = sfx:clone()
-      s._sfx = _sfx
-      luaspfx.sfx( false, nil, _sfx, params )
+      luaspfx.sfx( false, nil, sfx, params )
       _finish(state)
    end
    table.insert( vn._states, s )
@@ -1765,7 +1778,7 @@ end
 Plays an eerie sound.
 --]]
 function vn.sfxEerie( params )
-    return vn.sfx( vn._sfx.eerie, params )
+   return vn.sfx( vn._sfx.eerie, params )
 end
 
 --[[--
@@ -1921,7 +1934,7 @@ function vn.run()
          elseif s._type=="Jump" then
             table.insert( jumps, s.label )
          elseif s._type=="Menu" then
-            if type(s.items)=="table" then
+            if type(s.items)=="table" and s.handler==nil then
                for i,m in ipairs(s.items) do
                   table.insert( menu_jumps, m[2] )
                end
